@@ -154,3 +154,7 @@ def empty_to_None(x):
         return x
 
 
+def daterange(start_date, end_date):
+    for n in range(int((end_date - start_date).days)):
+        yield start_date + timedelta(n)
+
